var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
import { concurrently } from 'rxline';
import { files, pathMatch, readFile, mapExt, mapRoot } from 'rxline/fs';
import { post, save } from '@connectv/sdh';
import { initJss } from '../transport/setup-jss';
import { bundle } from './bundle';
import { content } from './content';
import { styles } from './styles';
import { loadToC } from './toc';
import { namespace } from './namespace';
export function build(config, builder, themeInstaller, webpackConfig) {
    return __awaiter(this, void 0, void 0, function* () {
        initJss();
        const _bundle = bundle(config, themeInstaller);
        const _styles = styles(config);
        const _toc = yield loadToC(config);
        return new Promise(resolve => {
            files('.', { root: config.src.base })
                .pick(pathMatch(config.src.pick))
                .drop(pathMatch(config.src.drop))
                .pipe(readFile(), content(builder, _toc, config, _styles), mapExt(() => '.html'), mapRoot(() => config.dest.html), post(_bundle.collect()), post(namespace(config)), save())
                .process(concurrently)
                .collect(() => {
                Promise.all([
                    save(_bundle, webpackConfig),
                    _styles.save(),
                ])
                    .then(resolve);
            });
        });
    });
}
//# sourceMappingURL=index.js.map