import Color from 'color';
import { funcTransport } from '@connectv/sdh/transport';
import { getRenderer } from '../../../../../transport/renderer';
import { SearchSwitcher } from './switcher';
export function postNavSearch() {
    let query = undefined;
    let switcher$;
    window.addEventListener('on-navigation-search', (event) => {
        query = event.detail.query;
    });
    window.addEventListener('navigation', () => {
        if (query)
            search(query);
        query = undefined;
    });
    const renderer = getRenderer();
    function search(query) {
        const q = query.toLowerCase();
        const highlights$ = [];
        const container$ = document.getElementById('-codedoc-container');
        if (container$) {
            const _scan = (el$) => {
                if (el$ instanceof Text) {
                    const text = el$.textContent;
                    const index = text === null || text === void 0 ? void 0 : text.toLowerCase().indexOf(q);
                    if (text && index !== undefined && index > -1) {
                        const before = text.substr(0, index);
                        const match = text.substr(index, query.length);
                        const after = text.substr(index + query.length);
                        let color = Color(window.getComputedStyle(el$.parentElement).color);
                        if (color.saturationv() < .2) {
                            color = color.isLight() ? 'teal' : 'yellow';
                        }
                        else
                            color = color.rotate(90).alpha(.35);
                        el$.textContent = after;
                        const before$ = document.createTextNode(before);
                        const match$ = renderer.create("span", { "data-no-search": true, style: `
                              background: ${color.toString()}; 
                              display: inline-block; 
                              vertical-align: middle;
                              transform-origin: center;
                              transition: transform .15s
                              ` }, match);
                        highlights$.push(match$);
                        renderer.render(renderer.create("fragment", null,
                            before$,
                            match$)).before(el$);
                        _scan(before$);
                        _scan(el$);
                    }
                }
                else {
                    if (el$ instanceof HTMLElement && el$.hasAttribute('data-no-search'))
                        return;
                    el$.childNodes.forEach(_scan);
                }
            };
            _scan(container$);
        }
        if (highlights$.length > 0) {
            if (switcher$)
                switcher$.remove();
            switcher$ = renderer.create(SearchSwitcher, { elements: highlights$ });
            renderer.render(switcher$).on(document.body);
        }
    }
    window._find = search;
}
export const postNavSearch$ = funcTransport(postNavSearch);
//# sourceMappingURL=index.js.map